parserFwk.pyparsing.ParseElementEnhance

Package parserFwk :: Module pyparsing :: Class ParseElementEnhance |
[frames | no frames]

## Type ParseElementEnhance

       object --+
                |
    ParserElement --+
                    |
                   ParseElementEnhance

Known Subclasses:
  `FollowedBy`, `Forward`, `NotAny`, `OneOrMore`, `Optional`, `SkipTo`, `TokenConverter`, `ZeroOrMore`

Abstract subclass of ParserElement, for combining and post-processing parsed tokens.

Method Summary
| `__init__(self, expr, savelist)`
| `__str__(self)`
| `checkRecursion(self, parseElementList)`
| ``ignore`(self, other)` Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns.
| ``leaveWhitespace`(self)` Disables the skipping of whitespace before matching the characters in the ParserElement's defined pattern.
| `parseImpl(self, instring, loc, doActions)`
| `streamline(self)`
| ``validate`(self, validateTrace)` Check defined expressions for valid structure, check for infinite recursive definitions.
Inherited from `ParserElement`: `__add__`, `__and__`, `__invert__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `normalizeParseActionArgs`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `skipIgnorables`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Instance Method Details

### ignore(self, other) Define expression to be ignored (e.g., comments) while doing pattern matching; may be called repeatedly, to define multiple comment or other ignorable patterns. Overrides: `parserFwk.pyparsing.ParserElement.ignore` (inherited documentation)

### leaveWhitespace(self) Disables the skipping of whitespace before matching the characters in the ParserElement's defined pattern. This is normally only used internally by the pyparsing module, but may be needed in some whitespace-sensitive grammars. Overrides: `parserFwk.pyparsing.ParserElement.leaveWhitespace` (inherited documentation)

### validate(self, validateTrace=[]) Check defined expressions for valid structure, check for infinite recursive definitions. Overrides: `parserFwk.pyparsing.ParserElement.validate` (inherited documentation)

Generated by Epydoc 2.1 on Wed Apr 11 17:02:38 2007 | http://epydoc.sf.net